Struct IoRead
struct IoRead<R> { ... }
where
R: io::Read
JSON input source that reads from a std::io input stream.
Implementations
impl<R> IoRead<R>
fn new(reader: R) -> SelfCreate a JSON input source to read from a std::io input stream.
When reading from a source against which short reads are not efficient, such as a
File, you will want to apply your own buffering because serde_json will not buffer the input. Seestd::io::BufReader.
impl<'de, R> Read for IoRead<R>
impl<R> Freeze for IoRead<R>
impl<R> RefUnwindSafe for IoRead<R>
impl<R> Send for IoRead<R>
impl<R> Sync for IoRead<R>
impl<R> Unpin for IoRead<R>
impl<R> UnsafeUnpin for IoRead<R>
impl<R> UnwindSafe for IoRead<R>
impl<T> Any for IoRead<R>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for IoRead<R>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for IoRead<R>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for IoRead<R>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for IoRead<R>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for IoRead<R>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for IoRead<R>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>