Struct SliceRead
struct SliceRead<'a> { ... }
JSON input source that reads from a slice of bytes.
Implementations
impl<'a> SliceRead<'a>
fn new(slice: &'a [u8]) -> SelfCreate a JSON input source to read from a slice of bytes.
impl<'a> Freeze for SliceRead<'a>
impl<'a> Read for SliceRead<'a>
impl<'a> RefUnwindSafe for SliceRead<'a>
impl<'a> Send for SliceRead<'a>
impl<'a> Sync for SliceRead<'a>
impl<'a> Unpin for SliceRead<'a>
impl<'a> UnsafeUnpin for SliceRead<'a>
impl<'a> UnwindSafe for SliceRead<'a>
impl<T> Any for SliceRead<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for SliceRead<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for SliceRead<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for SliceRead<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for SliceRead<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for SliceRead<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for SliceRead<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>