Read

Trait Read 

pub trait Read<'de>: Sealed { }
Trait used by the deserializer for iterating over input. This is manually “specialized” for iterating over &[u8]. Once feature(specialization) is stable we can use actual specialization.

This trait is sealed and cannot be implemented for types outside of serde_json.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'de, R> Read<'de> for &mut R
where R: Read<'de>,

Implementors

Source

impl<'a> Read<'a> for SliceRead<'a>

Source

impl<'a> Read<'a> for StrRead<'a>

Source

impl<'de, R> Read<'de> for IoRead<R>
where R: Read,

Available on crate feature std only.