Function to_raw_value
fn to_raw_value<T>(value: &T) -> Result<Box<RawValue>, Error>
where
T: ?Sized + Serialize
Convert a T into a boxed RawValue.
Example
// Upstream crate
#
// Local crate
use Serialize;
use ;
let my_thing = Thing ;
# assert_eq!;
Errors
This conversion can fail if T's implementation of Serialize decides to
fail, or if T contains a map with non-string keys.
use BTreeMap;
// The keys in this map are vectors, not strings.
let mut map = new;
map.insert;
println!;